==> racer-0.1.1.tgz: package/lib/mixin.subscribe/index.js <==
var empty, pathParser, setSubDatum;
var __slice = Array.prototype.slice;
pathParser = require('../pathParser');
empty = function() {};
module.exports = {
  init: function() {
    return this._storeSubs = {};
  },
  setupSocket: function(socket) {
    var self, _adapter;
    _adapter = (self = this)._adapter;
    return socket.on('connect', function() {
      var storeSubs;
      storeSubs = Object.keys(self._storeSubs);
      return socket.emit('sub', self._clientId, storeSubs, _adapter.version(), self._startId);
    });
  },
  proto: {
    subscribe: function() {
      var addPath, callback, key, path, paths, root, storeSubs, value, _i, _j, _len, _paths;
      _paths = 2 <= arguments.length ? __slice.call(arguments, 0, _i = arguments.length - 1) : (_i = 0, []), callback = arguments[_i++];
      if (typeof callback !== 'function') {
        _paths.push(callback);
        callback = empty;
      }
      paths = [];
      storeSubs = this._storeSubs;
      addPath = function(path) {
        var _j, _len, _ref, _results;
        _ref = pathParser.expand(path);
        _results = [];
        for (_j = 0, _len = _ref.length; _j < _len; _j++) {
          path = _ref[_j];
          if (storeSubs[path]) {
            return;
          }
          storeSubs[path] = 1;
          _results.push(paths.push(path));
        }
        return _results;
      };
      for (_j = 0, _len = _paths.length; _j < _len; _j++) {
        path = _paths[_j];
        if (typeof path === 'object') {
          for (key in path) {
            value = path[key];
            root = pathParser.split(value)[0];
            this.set(key, this.ref(root));
            addPath(value);
          }
        } else {
          addPath(path);
        }
      }
      if (!paths.length) {
        return callback();
      }
      return this._addSub(paths, callback);
    },
    unsubscribe: function() {
      var callback, paths, _i;
      paths = 2 <= arguments.length ? __slice.call(arguments, 0, _i = arguments.length - 1) : (_i = 0, []), callback = arguments[_i++];
      if (typeof callback !== 'function') {
        paths.push(callback);
        callback = empty;
      }
      throw new Error('Unimplemented: unsubscribe');
    },
    _addSub: function(paths, callback) {
      var self;
      self = this;
      if (!this.connected) {
        return callback();
      }
      return this.socket.emit('subAdd', this._clientId, paths, function(data, otData) {
        self._initSubData(data);
        self._initSubOtData(otData);
        return callback();
      });
    },
    _initSubData: function(data) {
      var adapter, datum, _i, _len;
      adapter = this._adapter;
      for (_i = 0, _len = data.length; _i < _len; _i++) {
        datum = data[_i];
        setSubDatum(adapter, datum);
      }
    },
    _initSubOtData: function(data) {
      var field, fields, path;
      fields = this.otFields;
      for (path in data) {
        field = data[path];
        fields[path] = field;
      }
    }
  }
};
setSubDatum = function(adapter, _arg) {
  var k, path, v, value, ver;
  path = _arg[0], value = _arg[1], ver = _arg[2];
  if (path === '') {
    if (typeof value === 'object') {
      for (k in value) {
        v = value[k];
        adapter.set(k, v, ver);
      }
      return;
    }
    throw 'Cannot subscribe to "' + path('"');
  }
  return adapter.set(path, value, ver);
};

==> racer-0.1.3.tgz: package/lib/mixin.subscribe/index.js <==
var empty, pathParser, setSubDatum;
var __slice = Array.prototype.slice;

pathParser = require('../pathParser');

empty = function() {};

module.exports = {
  init: function() {
    return this._storeSubs = {};
  },
  setupSocket: function(socket) {
    var self, _adapter;
    _adapter = (self = this)._adapter;
    return socket.on('connect', function() {
      var storeSubs;
      storeSubs = Object.keys(self._storeSubs);
      return socket.emit('sub', self._clientId, storeSubs, _adapter.version(), self._startId);
    });
  },
  proto: {
    subscribe: function() {
      var addPath, callback, key, path, paths, root, storeSubs, value, _i, _j, _len, _paths;
      _paths = 2 <= arguments.length ? __slice.call(arguments, 0, _i = arguments.length - 1) : (_i = 0, []), callback = arguments[_i++];
      if (typeof callback !== 'function') {
        _paths.push(callback);
        callback = empty;
      }
      paths = [];
      storeSubs = this._storeSubs;
      addPath = function(path) {
        var _j, _len, _ref, _results;
        _ref = pathParser.expand(path);
        _results = [];
        for (_j = 0, _len = _ref.length; _j < _len; _j++) {
          path = _ref[_j];
          if (storeSubs[path]) return;
          storeSubs[path] = 1;
          _results.push(paths.push(path));
        }
        return _results;
      };
      for (_j = 0, _len = _paths.length; _j < _len; _j++) {
        path = _paths[_j];
        if (typeof path === 'object') {
          for (key in path) {
            value = path[key];
            root = pathParser.split(value)[0];
            this.set(key, this.ref(root));
            addPath(value);
          }
        } else {
          addPath(path);
        }
      }
      if (!paths.length) return callback();
      return this._addSub(paths, callback);
    },
    unsubscribe: function() {
      var callback, paths, _i;
      paths = 2 <= arguments.length ? __slice.call(arguments, 0, _i = arguments.length - 1) : (_i = 0, []), callback = arguments[_i++];
      if (typeof callback !== 'function') {
        paths.push(callback);
        callback = empty;
      }
      throw new Error('Unimplemented: unsubscribe');
    },
    _addSub: function(paths, callback) {
      var self;
      self = this;
      if (!this.connected) return callback();
      return this.socket.emit('subAdd', this._clientId, paths, function(data, otData) {
        self._initSubData(data);
        self._initSubOtData(otData);
        return callback();
      });
    },
    _initSubData: function(data) {
      var adapter, datum, _i, _len;
      adapter = this._adapter;
      for (_i = 0, _len = data.length; _i < _len; _i++) {
        datum = data[_i];
        setSubDatum(adapter, datum);
      }
    },
    _initSubOtData: function(data) {
      var field, fields, path;
      fields = this.otFields;
      for (path in data) {
        field = data[path];
        fields[path] = field;
      }
    }
  }
};

setSubDatum = function(adapter, _arg) {
  var k, path, v, value, ver;
  path = _arg[0], value = _arg[1], ver = _arg[2];
  if (path === '') {
    if (typeof value === 'object') {
      for (k in value) {
        v = value[k];
        adapter.set(k, v, ver);
      }
      return;
    }
    throw 'Cannot subscribe to "' + path('"');
  }
  return adapter.set(path, value, ver);
};
